"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommunityListTemplatesCommand = void 0;
const os = require("os");
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const CommunityTemplatesResource_1 = require("../../../../shared/community/connect/CommunityTemplatesResource");
const ConnectExecutor_1 = require("../../../../shared/connect/services/ConnectExecutor");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-community', 'template.list');
/**
 * A command to fetch available community templates a community. This is just an sfdx wrapper around
 * the get available community templates connect endpoint
 */
class CommunityListTemplatesCommand extends command_1.SfdxCommand {
    async run() {
        const listTemplateCommand = new CommunityTemplatesResource_1.CommunityTemplatesResource(this.ux);
        return new ConnectExecutor_1.ConnectExecutor(listTemplateCommand, this.org).callConnectApi();
    }
}
exports.CommunityListTemplatesCommand = CommunityListTemplatesCommand;
CommunityListTemplatesCommand.requiresUsername = true;
CommunityListTemplatesCommand.description = messages.getMessage('description');
CommunityListTemplatesCommand.examples = messages.getMessage('examples').split(os.EOL);
//# sourceMappingURL=list.js.map